@@ -172,44 +172,6 @@ Collect Reuters financial statements for a particular security:
         "12 hours)")
     parser.set_defaults(func="quantrocket.fundamental._cli_collect_reuters_financials")
 
-    examples = """
-Collect Reuters estimates and actuals from Interactive Brokers and save to database.
-
-This data provides analyst estimates and actuals for a variety of indicators.
-
-Examples:
-
-Collect Reuters estimates and actuals for a universe of Japanese banks:
-
-    quantrocket fundamental collect-reuters-estimates --universes 'japan-bank'
-
-Collect Reuters estimates and actuals for a particular security:
-
-    quantrocket fundamental collect-reuters-estimates --sids FIBBG123456
-    """
-    parser = _subparsers.add_parser(
-        "collect-reuters-estimates",
-        help="collect Reuters estimates and actuals from Interactive Brokers and save to database",
-        epilog=examples,
-        formatter_class=argparse.RawDescriptionHelpFormatter)
-    parser.add_argument(
-        "-u", "--universes",
-        nargs="*",
-        metavar="UNIVERSE",
-        help="limit to these universes (must provide universes, sids, or both)")
-    parser.add_argument(
-        "-i", "--sids",
-        nargs="*",
-        metavar="SID",
-        help="limit to these sids (must provide universes, sids, or both)")
-    parser.add_argument(
-        "-f", "--force",
-        action="store_true",
-        help="collect estimates for all securities even if they were collected "
-        "recently (default is to skip securities that were updated in the last "
-        "12 hours)")
-    parser.set_defaults(func="quantrocket.fundamental._cli_collect_reuters_estimates")
-
     examples = """
 Collect Wall Street Horizon upcoming earnings announcement dates from Interactive
 Brokers and save to database.
@@ -821,8 +783,8 @@ minimal set of fields (several required fields will always be returned)
 Query estimates and actuals from the Reuters estimates database and
 download to file.
 
-You can query one or more indicator codes. Run `quantrocket fundamental reuters-codes` to see
-available codes.
+DEPRECATED. This data is no longer available from Interactive Brokers. Only
+data that was previously saved to the local database can be queried.
 
 Examples:
 
@@ -832,7 +794,7 @@ Query EPS estimates and actuals for a universe of Australian stocks:
     """
     parser = _subparsers.add_parser(
         "reuters-estimates",
-        help="query estimates and actuals from the Reuters estimates database and download to file",
+        help="[DEPRECATED] query estimates and actuals from the Reuters estimates database and download to file",
         epilog=examples,
         formatter_class=argparse.RawDescriptionHelpFormatter)
     parser.add_argument(
