@@ -28,15 +28,19 @@ data. To ingest the data, see `quantrocket zipline ingest`.
 
 Examples:
 
-Create a bundle for all US stocks:
+Create a minute data bundle for all US stocks:
 
     quantrocket zipline create-usstock-bundle usstock-1min
 
-Create a bundle based on a universe:
+Create a bundle for daily data only:
+
+    quantrocket zipline create-usstock-bundle usstock-1d --data-frequency daily
+
+Create a minute data bundle based on a universe:
 
     quantrocket zipline create-usstock-bundle usstock-tech-1min --universes us-tech
 
-Create a bundle of free sample data:
+Create a minute data bundle of free sample data:
 
     quantrocket zipline create-usstock-bundle usstock-free-1min --free
     """
@@ -52,15 +56,20 @@ Create a bundle of free sample data:
     parser.add_argument(
         "-i", "--sids",
         metavar="SID",
-        help="limit to these sids")
+        help="limit to these sids (only supported for minute data bundles)")
     parser.add_argument(
         "-u", "--universes",
         metavar="UNIVERSE",
-        help="limit to these universes")
+        help="limit to these universes (only supported for minute data bundles)")
     parser.add_argument(
         "--free",
         action="store_true",
         help="limit to free sample data")
+    parser.add_argument(
+        "-d", "--data-frequency",
+        choices=["daily", "d", "minute", "m"],
+        help="whether to collect minute data (which also includes daily data) or "
+        "only daily data. Default is minute data. Possible choices: %(choices)s")
     parser.set_defaults(func="quantrocket.zipline._cli_create_usstock_bundle")
 
     examples = """
@@ -267,7 +276,7 @@ Show current default bundle:
     parser.set_defaults(func="quantrocket.zipline._cli_get_or_set_default_bundle")
 
     examples = """
-Query minute data from a Zipline bundle and download to a CSV file.
+Query minute or daily data from a Zipline bundle and download to a CSV file.
 
 Examples:
 
@@ -278,7 +287,7 @@ Download a CSV of minute prices since 2015 for a single security from a bundle c
     """
     parser = _subparsers.add_parser(
         "get",
-        help="query minute data from a Zipline bundle and download to a CSV file",
+        help="query minute or daily data from a Zipline bundle and download to a CSV file",
         epilog=examples,
         formatter_class=argparse.RawDescriptionHelpFormatter)
     parser.add_argument(
@@ -294,6 +303,13 @@ Download a CSV of minute prices since 2015 for a single security from a bundle c
         "-e", "--end-date",
         metavar="YYYY-MM-DD",
         help="limit to history on or before this date")
+    filters.add_argument(
+        "-d", "--data-frequency",
+        choices=["daily", "d", "minute", "m"],
+        help="whether to query minute or daily data. If omitted, defaults to "
+        "minute data for minute bundles and to daily data for daily bundles. "
+        "This parameter only needs to be set to request daily data from a minute "
+        "bundle. Possible choices: %(choices)s")
     filters.add_argument(
         "-u", "--universes",
         nargs="*",
@@ -331,7 +347,7 @@ Download a CSV of minute prices since 2015 for a single security from a bundle c
         nargs="*",
         help="only return these fields (pass '?' or any invalid fieldname to see "
         "available fields)")
-    parser.set_defaults(func="quantrocket.zipline._cli_download_minute_file")
+    parser.set_defaults(func="quantrocket.zipline._cli_download_bundle_file")
 
     examples = """
 Backtest a Zipline strategy and write the test results to a CSV file.
@@ -358,7 +374,7 @@ logging backtest progress at annual intervals:
         help="the strategy to run (strategy filename without extension)")
     parser.add_argument(
         "-f", "--data-frequency",
-        choices=["daily", "minute"],
+        choices=["daily", "d", "minute", "m"],
         help="the data frequency to use. Possible choices: %(choices)s "
         "(default is minute)")
     parser.add_argument(
@@ -454,7 +470,7 @@ Trade a strategy defined in momentum-pipeline.py:
         "account in quantrocket.zipline.allocations.yml")
     parser.add_argument(
         "-f", "--data-frequency",
-        choices=["daily", "minute"],
+        choices=["daily", "d", "minute", "m"],
         help="the data frequency to use. Possible choices: %(choices)s "
         "(default is minute)")
     parser.set_defaults(func="quantrocket.zipline._cli_trade")
