@@ -293,6 +293,13 @@ def _insert_into(df, table_name, conn, on_conflict):
     if not df_bools.empty:
         df.loc[:, df_bools.columns] = df_bools.astype(int)
 
+    # Cast datetimes to str and replace space separator with T separator
+    # (replace is a no-op for dates, which are cast to str as YYYY-MM-DD)
+    df_dts = df.select_dtypes(["datetime", "datetimetz"])
+    if not df_dts.empty:
+        df.loc[:, df_dts.columns] = df_dts.astype(str).apply(
+            lambda col: col.str.replace(" ", "T"))
+
     df.to_csv(temp_file_name, index=False)
 
     # Close connection to avoid Database Is Locked
